@@ -1,16 +1,12 @@
 # This file is part of Flask-Multipass.
-# Copyright (C) 2015 - 2017 CERN
+# Copyright (C) 2015 - 2021 CERN
 #
 # Flask-Multipass is free software; you can redistribute it
 # and/or modify it under the terms of the Revised BSD License.
 
-from __future__ import unicode_literals
+from unittest.mock import MagicMock
 
 import pytest
-try:
-    from mock import MagicMock
-except ImportError:
-    from unittest.mock import MagicMock
 
 from flask_multipass import AuthInfo, AuthProvider, IdentityInfo, Multipass
 
